Index: net/ssl/client_cert_store_nss.h |
diff --git a/net/ssl/client_cert_store_nss.h b/net/ssl/client_cert_store_nss.h |
index d49d50f6a43298eaac20d85756a637fdf0647654..3f05267843ff96c06768b68486b71e735c9acccd 100644 |
--- a/net/ssl/client_cert_store_nss.h |
+++ b/net/ssl/client_cert_store_nss.h |
@@ -35,26 +35,24 @@ class NET_EXPORT ClientCertStoreNSS : public ClientCertStore { |
void GetClientCerts(const SSLCertRequestInfo& cert_request_info, |
const ClientCertListCallback& callback) override; |
- // Examines the certificates in |certs| to find all certificates that match |
- // the client certificate request in |request|, storing the matching |
- // certificates in |filtered_certs|. Any previous content of |filtered_certs| |
- // will be removed. |
+ // Examines the certificates in |identities| to find all certificates that |
+ // match the client certificate request in |request|, removing any that don't. |
+ // The remaining certs will be updated to include intermediates. |
// Must be called from a worker thread. |
- static void FilterCertsOnWorkerThread(const CertificateList& certs, |
- const SSLCertRequestInfo& request, |
- CertificateList* filtered_certs); |
+ static void FilterCertsOnWorkerThread(ClientCertIdentityList* identities, |
+ const SSLCertRequestInfo& request); |
// Retrieves all client certificates that are stored by NSS and adds them to |
// |certs|. |password_delegate| is used to unlock slots if required. |
// Must be called from a worker thread. |
static void GetPlatformCertsOnWorkerThread( |
- std::unique_ptr<crypto::CryptoModuleBlockingPasswordDelegate> |
+ scoped_refptr<crypto::CryptoModuleBlockingPasswordDelegate> |
password_delegate, |
- net::CertificateList* certs); |
+ ClientCertIdentityList* identities); |
private: |
- CertificateList GetAndFilterCertsOnWorkerThread( |
- std::unique_ptr<crypto::CryptoModuleBlockingPasswordDelegate> |
+ ClientCertIdentityList GetAndFilterCertsOnWorkerThread( |
+ scoped_refptr<crypto::CryptoModuleBlockingPasswordDelegate> |
password_delegate, |
const SSLCertRequestInfo* request); |
@@ -35,26 +35,24 @@ class NET_EXPORT ClientCertStoreNSS : public ClientCertStore { |
// Retrieves all client certificates that are stored by NSS and adds them to |
- // |certs|. |password_delegate| is used to unlock slots if required. |
+ // |identities|. |password_delegate| is used to unlock slots if required. |
// Must be called from a worker thread. |
static void GetPlatformCertsOnWorkerThread( |